#ifndef NT2_INCLUDE_FUNCTIONS_COTANGENT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COTANGENT_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/cotangent.hpp>

#endif
